Package: CHBUtils
Title: "Useful utility functions used at the core"
Description: "Useful utility functions used at the core"
Version: 0.1
Authors@R: c(person("Rory", "Kirchner", email="rory.kirchner@gmail.com",
    role = c("aut", "cre", "ths")),
    person("John", "Hutchinson", email="jnhutchinson@gmail.com",
    role = c("aut")),
    person("Oliver", "Hofmann", email="ohofmann@hsph.harvard.edu",
    role = c("aut")),
    person("Brad", "Chapman", email="chapmanb@50mail.com",
    role = c("aut")),
    person("Meeta", "Mistry", email="meeta.mistry@gmail.com",
    role = c("aut")),
    person("Lorena", "Pantano", email="lorena.pantano@gmail.com",
    role = c("aut")))
Depends:
    R (>= 3.0.0)
License: "MIT"
LazyData: true
RoxygenNote: 5.0.1
