CHBUtils
=========
[![Build Status](https://api.travis-ci.org/hbc/CHBUtils.png)](http://travis-ci.org/hbc/CHBUtils)

Utility functions in R

# Install
```
install.packages("devtools")
library(devtools)
install_git("git://github.com/hbc/CHBUtils.git")
```
